# Table of Contents

- [viewing-and-analyzing-diagrams](<./viewing-and-analyzing-diagrams.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
  - [Table of Contents](<./SAP-LeanIX/Table-of-Contents.md>)
- [Viewing and Analyzing Diagrams](<./Viewing-and-Analyzing-Diagrams.md>)
  - [Overview](<./Viewing-and-Analyzing-Diagrams/Overview.md>)
  - [Viewing a Diagram](<./Viewing-and-Analyzing-Diagrams/Viewing-a-Diagram.md>)
  - [Basic View Controls](<./Viewing-and-Analyzing-Diagrams/Basic-View-Controls.md>)
  - [Navigating Between Linked Diagrams](<./Viewing-and-Analyzing-Diagrams/Navigating-Between-Linked-Diagrams.md>)
  - [Applying Views to Color‑Code Fact Sheets](<./Viewing-and-Analyzing-Diagrams/Applying-Views-to-ColorCode-Fact-Sheets.md>)
  - [Including Custom Fact Sheet Fields in Views](<./Viewing-and-Analyzing-Diagrams/Including-Custom-Fact-Sheet-Fields-in-Views.md>)
  - [Including Tag Groups in Views](<./Viewing-and-Analyzing-Diagrams/Including-Tag-Groups-in-Views.md>)
  - [Reverting View Colors](<./Viewing-and-Analyzing-Diagrams/Reverting-View-Colors.md>)
  - [Filtering Fact Sheets and Relations in Diagrams](<./Viewing-and-Analyzing-Diagrams/Filtering-Fact-Sheets-and-Relations-in-Diagrams.md>)
  - [Showing and Hiding Filtered Shapes](<./Viewing-and-Analyzing-Diagrams/Showing-and-Hiding-Filtered-Shapes.md>)
  - [Filter Persistence](<./Viewing-and-Analyzing-Diagrams/Filter-Persistence.md>)
  - [Toggling Layers to Focus Analysis](<./Viewing-and-Analyzing-Diagrams/Toggling-Layers-to-Focus-Analysis.md>)
  - [Viewing Fact Sheet Details](<./Viewing-and-Analyzing-Diagrams/Viewing-Fact-Sheet-Details.md>)
  - [Customizing the Side Panel](<./Viewing-and-Analyzing-Diagrams/Customizing-the-Side-Panel.md>)
  - [Viewing Linked Architecture Decisions](<./Viewing-and-Analyzing-Diagrams/Viewing-Linked-Architecture-Decisions.md>)
  - [Understanding Interface Arrows in Data Flow Diagrams](<./Viewing-and-Analyzing-Diagrams/Understanding-Interface-Arrows-in-Data-Flow-Diagrams.md>)
  - [Hiding Inventory Updates](<./Viewing-and-Analyzing-Diagrams/Hiding-Inventory-Updates.md>)
  - [Was this page helpful?](<./Viewing-and-Analyzing-Diagrams/Was-this-page-helpful.md>)
